[libgtop/wip/diskio] Renamed procdiskio to procio



commit 1bf16bfffd28e6724c35589e49db10a10cae594d
Author: Robert Roth <robert roth off gmail com>
Date:   Fri May 12 05:08:41 2017 +0300

    Renamed procdiskio to procio

 examples/diskio.c                          |    8 ++--
 examples/sysdeps.c                         |    6 ++--
 examples/timings.c                         |    6 ++--
 features.def                               |    2 +-
 include/glibtop/Makefile.am                |    2 +-
 include/glibtop/command.h                  |    2 +-
 include/glibtop/{procdiskio.h => procio.h} |   42 ++++++++++++++--------------
 include/glibtop/sysdeps.h                  |    4 +-
 include/glibtop/union.h                    |    4 +-
 lib/Makefile.am                            |    2 +-
 lib/command.c                              |    2 +-
 lib/libgtop.sym                            |    4 +-
 lib/sysdeps.c                              |   10 +++---
 src/daemon/main.c                          |    8 ++--
 src/daemon/slave.c                         |    8 ++--
 sysdeps/common/default.c                   |    6 ++--
 sysdeps/common/sysdeps_suid.c              |    4 +-
 sysdeps/freebsd/Makefile.am                |    2 +-
 sysdeps/freebsd/glibtop_server.h           |    2 +-
 sysdeps/freebsd/{procdiskio.c => procio.c} |   12 ++++----
 sysdeps/linux/Makefile.am                  |    2 +-
 sysdeps/linux/glibtop_server.h             |    2 +-
 sysdeps/linux/{procdiskio.c => procio.c}   |   18 ++++++------
 sysdeps/stub/{procdiskio.c => procio.c}    |   12 ++++----
 sysdeps/stub_suid/glibtop_server.h         |    2 +-
 25 files changed, 86 insertions(+), 86 deletions(-)
---
diff --git a/examples/diskio.c b/examples/diskio.c
index 60dd933..112b472 100644
--- a/examples/diskio.c
+++ b/examples/diskio.c
@@ -3,7 +3,7 @@
 #endif
 
 #include <glibtop.h>
-#include <glibtop/procdiskio.h>
+#include <glibtop/procio.h>
 
 #include <stdlib.h>
 
@@ -11,13 +11,13 @@
 
 static void show_diskio(pid_t pid)
 {
-  glibtop_proc_diskio diskio;
+  glibtop_proc_io io;
 
-  glibtop_get_proc_diskio (&diskio, pid);
+  glibtop_get_proc_io (&io, pid);
 
   printf("<%ld>\t", (long)pid);
 
-  printf("flags: %08lx rchar : %lu, wchar : %lu, read_bytes : %lu, write_bytes : %lu\n", (unsigned 
long)diskio.flags, diskio.rchar, diskio.wchar, diskio.rbytes, diskio.wbytes);
+  printf("flags: %08lx rchar : %lu, wchar : %lu, read_bytes : %lu, write_bytes : %lu\n", (unsigned 
long)io.flags, io.rchar, io.wchar, io.rbytes, io.wbytes);
 
 }
 
diff --git a/examples/sysdeps.c b/examples/sysdeps.c
index a63a354..559f93e 100644
--- a/examples/sysdeps.c
+++ b/examples/sysdeps.c
@@ -95,7 +95,7 @@ main (int argc, char *argv [])
                "\tproc_segment:\t%d\t0x%08lx\n"
                "\tproc_args:\t%d\t0x%08lx\n"
                "\tproc_map:\t%d\t0x%08lx\n"
-               "\tproc_diskio:\t%d\t0x%08lx\n\n"
+               "\tproc_io:\t%d\t0x%08lx\n\n"
                "\tmountlist:\t%d\t0x%08lx\n"
                "\tfsusage:\t%d\t0x%08lx\n\n"
                "\tnetload:\t%d\t0x%08lx\n"
@@ -138,8 +138,8 @@ main (int argc, char *argv [])
                (unsigned long) sysdeps.proc_args,
                FEATURE_CHECK(PROC_MAP),
                (unsigned long) sysdeps.proc_map,
-               FEATURE_CHECK(PROC_DISKIO),
-               (unsigned long) sysdeps.proc_diskio,
+               FEATURE_CHECK(PROC_IO),
+               (unsigned long) sysdeps.proc_io,
                FEATURE_CHECK(MOUNTLIST),
                (unsigned long) sysdeps.mountlist,
                FEATURE_CHECK(FSUSAGE),
diff --git a/examples/timings.c b/examples/timings.c
index f7537a7..15bc197 100644
--- a/examples/timings.c
+++ b/examples/timings.c
@@ -416,7 +416,7 @@ main (int argc, char *argv [])
        getrusage (RUSAGE_SELF, &rusage_start);
 
        for (c = 0; c < PROFILE_COUNT; c++)
-               glibtop_get_proc_diskio (&data.proc_diskio, pid);
+               glibtop_get_proc_io (&data.proc_io, pid);
 
        getrusage (RUSAGE_SELF, &rusage_end);
 
@@ -426,8 +426,8 @@ main (int argc, char *argv [])
        libgtop_timersub (&rusage_end.ru_stime, &rusage_start.ru_stime,
                          &elapsed_stime);
 
-       printf ("Proc_DiskIo  (0x%08lx): %7lu - %9.2Lf - %9.2Lf\n",
-               (unsigned long) data.proc_diskio.flags, PROFILE_COUNT,
+       printf ("Proc_Io  (0x%08lx): %7lu - %9.2Lf - %9.2Lf\n",
+               (unsigned long) data.proc_io.flags, PROFILE_COUNT,
                (long double) ELAPSED_UTIME / PROFILE_COUNT,
                (long double) ELAPSED_STIME / PROFILE_COUNT);
 
diff --git a/features.def b/features.def
index 065d8fa..faab87b 100644
--- a/features.def
+++ b/features.def
@@ -24,5 +24,5 @@ void|ppp|ushort(device)
 char **|netlist
 char **|proc_wd|pid_t(pid)
 guint16*|proc_affinity|pid_t(pid)
-void|proc_diskio|pid_t(pid)
+void|proc_io|pid_t(pid)
 
diff --git a/include/glibtop/Makefile.am b/include/glibtop/Makefile.am
index b797385..6d0e055 100644
--- a/include/glibtop/Makefile.am
+++ b/include/glibtop/Makefile.am
@@ -9,7 +9,7 @@ glibtop_HEADERS         = close.h loadavg.h prockernel.h procstate.h \
                          parameter.h mountlist.h fsusage.h procmap.h signal.h \
                          sysinfo.h ppp.h procargs.h netload.h \
                          procwd.h procaffinity.h \
-              procdiskio.h \
+              procio.h \
                          netlist.h procopenfiles.h open.h
 
 noinst_HEADERS         = error.h write.h read_data.h read.h init_hooks.h machine.h \
diff --git a/include/glibtop/command.h b/include/glibtop/command.h
index 6e9dc07..9a0e47b 100644
--- a/include/glibtop/command.h
+++ b/include/glibtop/command.h
@@ -59,7 +59,7 @@ G_BEGIN_DECLS
 #define GLIBTOP_CMND_PROC_OPEN_FILES   25
 #define GLIBTOP_CMND_PROC_WD           26
 #define GLIBTOP_CMND_PROC_AFFINITY     27
-#define GLIBTOP_CMND_PROC_DISKIO       28
+#define GLIBTOP_CMND_PROC_IO   28
 
 #define GLIBTOP_MAX_CMND               29
 
diff --git a/include/glibtop/sysdeps.h b/include/glibtop/sysdeps.h
index 39c2dad..6b5682d 100644
--- a/include/glibtop/sysdeps.h
+++ b/include/glibtop/sysdeps.h
@@ -53,7 +53,7 @@ G_BEGIN_DECLS
 #define GLIBTOP_SYSDEPS_PROC_OPEN_FILES        24
 #define GLIBTOP_SYSDEPS_PROC_WD                25
 #define GLIBTOP_SYSDEPS_PROC_AFFINITY  26
-#define GLIBTOP_SYSDEPS_PROC_DISKIO    27
+#define GLIBTOP_SYSDEPS_PROC_IO        27
 
 #define GLIBTOP_MAX_SYSDEPS            28
 
@@ -94,7 +94,7 @@ struct _glibtop_sysdeps
        guint64 ppp;                    /* glibtop_ppp          */
        guint64 proc_wd;                /* glibtop_proc_wd      */
        guint64 proc_affinity;          /* glibtop_proc_affinity */
-       guint64 proc_diskio;            /* glibtop_proc_diskio */
+       guint64 proc_io;                /* glibtop_proc_io */
 };
 
 void glibtop_get_sysdeps (glibtop_sysdeps *buf);
diff --git a/include/glibtop/union.h b/include/glibtop/union.h
index 9148c40..334f021 100644
--- a/include/glibtop/union.h
+++ b/include/glibtop/union.h
@@ -44,7 +44,7 @@
 #include <glibtop/procopenfiles.h>
 #include <glibtop/procwd.h>
 #include <glibtop/procaffinity.h>
-#include <glibtop/procdiskio.h>
+#include <glibtop/procio.h>
 
 #include <glibtop/mountlist.h>
 #include <glibtop/fsusage.h>
@@ -85,7 +85,7 @@ union _glibtop_union
        glibtop_proc_open_files proc_open_files;
        glibtop_proc_wd         proc_wd;
        glibtop_proc_affinity   proc_affinity;
-       glibtop_proc_diskio     proc_diskio;
+       glibtop_proc_io proc_io;
 };
 
 G_END_DECLS
diff --git a/lib/Makefile.am b/lib/Makefile.am
index b23ba5e..90b8286 100644
--- a/lib/Makefile.am
+++ b/lib/Makefile.am
@@ -35,7 +35,7 @@ introspection_sources = $(libgtop_2_0_la_SOURCES) lib.c ../glibtop.h ../libgtopc
                        ../include/glibtop/procsignal.h ../include/glibtop/union.h 
../include/glibtop/gnuserv.h \
                        ../include/glibtop/parameter.h ../include/glibtop/mountlist.h 
../include/glibtop/fsusage.h ../include/glibtop/procmap.h ../include/glibtop/signal.h \
                        ../include/glibtop/sysinfo.h ../include/glibtop/ppp.h ../include/glibtop/procargs.h 
../include/glibtop/netload.h \
-                       ../include/glibtop/procwd.h ../include/glibtop/procaffinity.h 
../include/glibtop/procdiskio.h \
+                       ../include/glibtop/procwd.h ../include/glibtop/procaffinity.h 
../include/glibtop/procio.h \
                        ../include/glibtop/netlist.h ../include/glibtop/procopenfiles.h 
../include/glibtop/open.h
 
 GTop-2.0.gir: libgtop-2.0.la
diff --git a/lib/command.c b/lib/command.c
index c2ad44d..b6ccf1f 100644
--- a/lib/command.c
+++ b/lib/command.c
@@ -68,7 +68,7 @@ glibtop_call_l (glibtop *server, unsigned command, size_t send_size,
          CHECK_CMND(GLIBTOP_CMND_PROC_OPEN_FILES);
          CHECK_CMND(GLIBTOP_CMND_PROC_WD);
          CHECK_CMND(GLIBTOP_CMND_PROC_AFFINITY);
-         CHECK_CMND(GLIBTOP_CMND_PROC_DISKIO);
+         CHECK_CMND(GLIBTOP_CMND_PROC_IO);
        default:
          glibtop_error_r(server, "CALL: command UNKNOWN(%d) sending %lu bytes", command, (unsigned 
long)send_size); break;
        }
diff --git a/lib/libgtop.sym b/lib/libgtop.sym
index 484b906..afa9d07 100644
--- a/lib/libgtop.sym
+++ b/lib/libgtop.sym
@@ -52,8 +52,8 @@ glibtop_get_shm_limits
 glibtop_get_shm_limits_l
 glibtop_get_proc_affinity
 glibtop_get_proc_affinity_l
-glibtop_get_proc_diskio
-glibtop_get_proc_diskio_l
+glibtop_get_proc_io
+glibtop_get_proc_io_l
 glibtop_get_swap
 glibtop_get_swap_l
 glibtop_get_sysdeps
diff --git a/lib/sysdeps.c b/lib/sysdeps.c
index 47333f9..e942fd4 100644
--- a/lib/sysdeps.c
+++ b/lib/sysdeps.c
@@ -49,7 +49,7 @@ GLIBTOP_SUID_NETLIST +
 GLIBTOP_SUID_PROC_WD +
 GLIBTOP_SUID_PROC_AFFINITY +
 GLIBTOP_SUID_PPP +
-GLIBTOP_SUID_PROC_DISKIO;
+GLIBTOP_SUID_PROC_IO;
 
 const _glibtop_init_func_t _glibtop_init_hook_s [] = {
 #if !GLIBTOP_SUID_CPU
@@ -121,8 +121,8 @@ const _glibtop_init_func_t _glibtop_init_hook_s [] = {
 #if !GLIBTOP_SUID_PPP
        _glibtop_init_ppp_s,
 #endif
-#if !GLIBTOP_SUID_PROC_DISKIO
-       _glibtop_init_proc_diskio_s,
+#if !GLIBTOP_SUID_PROC_IO
+       _glibtop_init_proc_io_s,
 #endif
        NULL
 };
@@ -197,8 +197,8 @@ const _glibtop_init_func_t _glibtop_init_hook_p [] = {
 #if GLIBTOP_SUID_PPP
        _glibtop_init_ppp_p,
 #endif
-#if GLIBTOP_SUID_PROC_DISKIO
-       _glibtop_init_proc_diskio_p,
+#if GLIBTOP_SUID_PROC_IO
+       _glibtop_init_proc_io_p,
 #endif
        NULL
 };
diff --git a/src/daemon/main.c b/src/daemon/main.c
index 1486876..b51addf 100644
--- a/src/daemon/main.c
+++ b/src/daemon/main.c
@@ -221,10 +221,10 @@ handle_parent_connection (int s)
            do_output (s, resp, _offset_data (fsusage),
                       0, NULL);
            break;
-    case GLIBTOP_CMND_PROC_DISKIO:
-           glibtop_get_proc_diskio_l
-               (server, &resp->u.data.proc_diskio, parameter);
-           do_output (s, resp, _offset_data (proc_diskio),
+    case GLIBTOP_CMND_PROC_IO:
+           glibtop_get_proc_io_l
+               (server, &resp->u.data.proc_io, parameter);
+           do_output (s, resp, _offset_data (proc_io),
                       0, NULL);
            break;
        case GLIBTOP_CMND_PPP:
diff --git a/src/daemon/slave.c b/src/daemon/slave.c
index ea0c674..e15f1ef 100644
--- a/src/daemon/slave.c
+++ b/src/daemon/slave.c
@@ -209,11 +209,11 @@ handle_slave_command (glibtop_command *cmnd, glibtop_response *resp,
                resp->offset = _offset_data (proc_time);
                break;
 #endif
-#if GLIBTOP_SUID_PROC_DISKIO
-       case GLIBTOP_CMND_PROC_DISKIO:
+#if GLIBTOP_SUID_PROC_IO
+       case GLIBTOP_CMND_PROC_IO:
                memcpy (&pid, parameter, sizeof (pid_t));
-               glibtop_get_proc_diskio_p
-                       (server, &resp->u.data.proc_diskio, pid);
+               glibtop_get_proc_io_p
+                       (server, &resp->u.data.proc_io, pid);
                resp->offset = _offset_data (proc_time);
                break;
 #endif
diff --git a/sysdeps/common/sysdeps_suid.c b/sysdeps/common/sysdeps_suid.c
index 70dd225..2495317 100644
--- a/sysdeps/common/sysdeps_suid.c
+++ b/sysdeps/common/sysdeps_suid.c
@@ -90,8 +90,8 @@ const _glibtop_init_func_t _glibtop_init_hook_p [] = {
 #if GLIBTOP_SUID_PPP
        _glibtop_init_ppp_p,
 #endif
-#if GLIBTOP_SUID_PROC_DISKIO
-       _glibtop_init_proc_diskio_p,
+#if GLIBTOP_SUID_PROC_IO
+       _glibtop_init_proc_io_p,
 #endif
        NULL
 };
diff --git a/sysdeps/freebsd/Makefile.am b/sysdeps/freebsd/Makefile.am
index 5d92dc0..7cacb70 100644
--- a/sysdeps/freebsd/Makefile.am
+++ b/sysdeps/freebsd/Makefile.am
@@ -16,7 +16,7 @@ libgtop_sysdeps_suid_2_0_la_SOURCES   = suid_open.c close.c swap.c \
                                  proclist.c procstate.c procuid.c \
                                  proctime.c procmem.c procsignal.c \
                                  prockernel.c procsegment.c procargs.c \
-                                 procdiskio.c \
+                                 procio.c \
                                  procmap.c netload.c ppp.c
 
 libgtop_sysdeps_suid_2_0_la_LDFLAGS    = $(LT_VERSION_INFO)
diff --git a/sysdeps/freebsd/glibtop_server.h b/sysdeps/freebsd/glibtop_server.h
index 6d6b73f..d908ea7 100644
--- a/sysdeps/freebsd/glibtop_server.h
+++ b/sysdeps/freebsd/glibtop_server.h
@@ -47,7 +47,7 @@ G_BEGIN_DECLS
 #define GLIBTOP_SUID_NETLIST           0
 #define GLIBTOP_SUID_PROC_WD           0
 #define GLIBTOP_SUID_PROC_AFFINITY     0
-#define GLIBTOP_SUID_PROC_DISKIO       (1 << GLIBTOP_SYSDEPS_PROC_DISKIO)
+#define GLIBTOP_SUID_PROC_IO   (1 << GLIBTOP_SYSDEPS_PROC_IO)
 
 G_END_DECLS
 
diff --git a/sysdeps/freebsd/procdiskio.c b/sysdeps/freebsd/procio.c
similarity index 76%
rename from sysdeps/freebsd/procdiskio.c
rename to sysdeps/freebsd/procio.c
index ed82586..27a7a0b 100644
--- a/sysdeps/freebsd/procdiskio.c
+++ b/sysdeps/freebsd/procio.c
@@ -21,23 +21,23 @@
 
 #include <config.h>
 #include <glibtop.h>
-#include <glibtop/procdiskio.h>
+#include <glibtop/procio.h>
 
-static const unsigned long _glibtop_sysdeps_proc_diskio = 0;
+static const unsigned long _glibtop_sysdeps_proc_io = 0;
 
 /* Init function. */
 
 void
-_glibtop_init_proc_diskio_p (glibtop *server)
+_glibtop_init_proc_io_p (glibtop *server)
 {
-       server->sysdeps.proc_diskio = _glibtop_sysdeps_proc_diskio;
+       server->sysdeps.proc_io = _glibtop_sysdeps_proc_io;
 }
 
 /* Provides detailed information about a process. */
 
 void
-glibtop_get_proc_diskio_p (glibtop *server, glibtop_proc_diskio *buf,
+glibtop_get_proc_io_p (glibtop *server, glibtop_proc_io *buf,
                         pid_t pid)
 {
-       memset (buf, 0, sizeof (glibtop_proc_diskio));
+       memset (buf, 0, sizeof (glibtop_proc_io));
 }
diff --git a/sysdeps/linux/Makefile.am b/sysdeps/linux/Makefile.am
index 0657fdc..7baabe0 100644
--- a/sysdeps/linux/Makefile.am
+++ b/sysdeps/linux/Makefile.am
@@ -10,7 +10,7 @@ libgtop_sysdeps_2_0_la_SOURCES        = open.c close.c cpu.c mem.c swap.c \
                                  proctime.c procmem.c procsignal.c prockernel.c \
                                  procsegment.c procargs.c procmap.c siglist.c \
                                  sysinfo.c netload.c ppp.c glibtop_private.c \
-                                 mountlist.c  procaffinity.c procdiskio.c \
+                                 mountlist.c  procaffinity.c procio.c \
                                  fsusage.c netlist.c procopenfiles.c procwd.c
 
 libgtop_sysdeps_2_0_la_LIBADD  =  @GLIB_LIBS@
diff --git a/sysdeps/linux/glibtop_server.h b/sysdeps/linux/glibtop_server.h
index db81b71..8e591ea 100644
--- a/sysdeps/linux/glibtop_server.h
+++ b/sysdeps/linux/glibtop_server.h
@@ -46,6 +46,6 @@
 #define GLIBTOP_SUID_PROC_AFFINITY     0
 #define GLIBTOP_SUID_PPP               0
 #define GLIBTOP_SUID_PROC_FILE         0
-#define GLIBTOP_SUID_PROC_DISKIO       0
+#define GLIBTOP_SUID_PROC_IO   0
 
 #endif /* __LINUX__GLIBTOP_SERVER_H__ */
diff --git a/sysdeps/linux/procdiskio.c b/sysdeps/linux/procio.c
similarity index 76%
rename from sysdeps/linux/procdiskio.c
rename to sysdeps/linux/procio.c
index 08bd553..55a37fe 100644
--- a/sysdeps/linux/procdiskio.c
+++ b/sysdeps/linux/procio.c
@@ -22,29 +22,29 @@
 #include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/procdiskio.h>
+#include <glibtop/procio.h>
 
 #include "glibtop_private.h"
 
-static const unsigned long _glibtop_sysdeps_proc_diskio =
-(1L << GLIBTOP_PROC_DISKIO_RCHAR) + (1L << GLIBTOP_PROC_DISKIO_WCHAR) +
-(1L << GLIBTOP_PROC_DISKIO_RBYTES) + (1L << GLIBTOP_PROC_DISKIO_WBYTES);
+static const unsigned long _glibtop_sysdeps_proc_io =
+(1L << GLIBTOP_PROC_IO_RCHAR) + (1L << GLIBTOP_PROC_IO_WCHAR) +
+(1L << GLIBTOP_PROC_IO_RBYTES) + (1L << GLIBTOP_PROC_IO_WBYTES);
 
 /* Init function. */
 
 void
-_glibtop_init_proc_diskio_s (glibtop *server)
+_glibtop_init_proc_io_s (glibtop *server)
 {
-       server->sysdeps.proc_diskio = _glibtop_sysdeps_proc_diskio;
+       server->sysdeps.proc_io = _glibtop_sysdeps_proc_io;
 }
 
 /* Provides detailed information about a process. */
 
 void
-glibtop_get_proc_diskio_s (glibtop *server, glibtop_proc_diskio *buf, pid_t pid)
+glibtop_get_proc_io_s (glibtop *server, glibtop_proc_io *buf, pid_t pid)
 {
        char buffer [BUFSIZ], *p;
-    memset (buf, 0, sizeof (glibtop_proc_diskio));
+    memset (buf, 0, sizeof (glibtop_proc_io));
 
     if (server->os_version_code < LINUX_VERSION_CODE(2, 6, 20))
       return;
@@ -66,5 +66,5 @@ glibtop_get_proc_diskio_s (glibtop *server, glibtop_proc_diskio *buf, pid_t pid)
     p = skip_token (p);
     buf->wbytes = g_ascii_strtoull (p, &p, 10);    
 
-    buf->flags = _glibtop_sysdeps_proc_diskio;
+    buf->flags = _glibtop_sysdeps_proc_io;
 }
diff --git a/sysdeps/stub/procdiskio.c b/sysdeps/stub/procio.c
similarity index 76%
rename from sysdeps/stub/procdiskio.c
rename to sysdeps/stub/procio.c
index 455fec6..a4846ae 100644
--- a/sysdeps/stub/procdiskio.c
+++ b/sysdeps/stub/procio.c
@@ -21,23 +21,23 @@
 
 #include <config.h>
 #include <glibtop.h>
-#include <glibtop/procdiskio.h>
+#include <glibtop/procio.h>
 
-static const unsigned long _glibtop_sysdeps_proc_diskio = 0;
+static const unsigned long _glibtop_sysdeps_proc_io = 0;
 
 /* Init function. */
 
 void
-_glibtop_init_proc_diskio_s (glibtop *server)
+_glibtop_init_proc_io_s (glibtop *server)
 {
-       server->sysdeps.proc_diskio = _glibtop_sysdeps_proc_diskio;
+       server->sysdeps.proc_io = _glibtop_sysdeps_proc_io;
 }
 
 /* Provides detailed information about a process. */
 
 void
-glibtop_get_proc_diskio_s (glibtop *server, glibtop_proc_diskio *buf,
+glibtop_get_proc_io_s (glibtop *server, glibtop_proc_io *buf,
                         pid_t pid)
 {
-       memset (buf, 0, sizeof (glibtop_proc_diskio));
+       memset (buf, 0, sizeof (glibtop_proc_io));
 }
diff --git a/sysdeps/stub_suid/glibtop_server.h b/sysdeps/stub_suid/glibtop_server.h
index ef0b191..15fe2e1 100644
--- a/sysdeps/stub_suid/glibtop_server.h
+++ b/sysdeps/stub_suid/glibtop_server.h
@@ -45,7 +45,7 @@ G_BEGIN_DECLS
 #define GLIBTOP_SUID_NETLOAD           (1 << GLIBTOP_SYSDEPS_NETLOAD)
 #define GLIBTOP_SUID_NETLIST           0
 #define GLIBTOP_SUID_PPP               (1 << GLIBTOP_SYSDEPS_PPP)
-#define GLIBTOP_SUID_PROC_DISKIO       (1 << GLIBTOP_SYSDEPS_PROC_DISKIO)
+#define GLIBTOP_SUID_PROC_IO   (1 << GLIBTOP_SYSDEPS_PROC_IO)
 
 G_END_DECLS
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/include/glibtop/procdiskio.h b/include/glibtop/procio.h
similarity index 65%
rename from include/glibtop/procdiskio.h
rename to include/glibtop/procio.h
index 6545ab3..48e2c61 100644
--- a/include/glibtop/procdiskio.h
+++ b/include/glibtop/procio.h
@@ -19,27 +19,27 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef __GLIBTOP_PROCDISKIO_H__
-#define __GLIBTOP_PROCDISKIO_H__
+#ifndef __GLIBTOP_PROCIO_H__
+#define __GLIBTOP_PROCIO_H__
 
 #include <glibtop.h>
 #include <glibtop/global.h>
 
 G_BEGIN_DECLS
 
-#define GLIBTOP_PROC_DISKIO_RCHAR      0
-#define GLIBTOP_PROC_DISKIO_WCHAR      1
-#define GLIBTOP_PROC_DISKIO_RBYTES     2
-#define GLIBTOP_PROC_DISKIO_WBYTES     3
+#define GLIBTOP_PROC_IO_RCHAR  0
+#define GLIBTOP_PROC_IO_WCHAR  1
+#define GLIBTOP_PROC_IO_RBYTES 2
+#define GLIBTOP_PROC_IO_WBYTES 3
 
-#define GLIBTOP_MAX_PROC_DISKIO                3
+#define GLIBTOP_MAX_PROC_IO            3
 
-typedef struct _glibtop_proc_diskio    glibtop_proc_diskio;
+typedef struct _glibtop_proc_io        glibtop_proc_io;
 
 /* Time section */
 
 /**
- * glibtop_proc_diskio:
+ * glibtop_proc_io:
  * @rchar: The number of bytes which this task has caused to be read from storage. This
  * is simply the sum of bytes which this process passed to read() and pread(), also including tty IO,
  * and it is unaffected by whether or not actual physical disk IO was required.
@@ -51,10 +51,10 @@ typedef struct _glibtop_proc_diskio glibtop_proc_diskio;
  * @wbytes: Attempt to count the number of bytes which this process caused to be sent to
  * the storage layer. This is done at page-dirtying time.
  *
  * Process disk io data filled by glibtop_get_proc_diskio().
  *
  */
-struct _glibtop_proc_diskio
+struct _glibtop_proc_io
 {
     /*< private >*/
        guint64 flags;
@@ -66,22 +66,22 @@ struct _glibtop_proc_diskio
 };
 
 
-void glibtop_get_proc_diskio (glibtop_proc_diskio *buf, pid_t pid);
+void glibtop_get_proc_io (glibtop_proc_io *buf, pid_t pid);
 
-#if GLIBTOP_SUID_PROC_DISKIO
-#define glibtop_get_proc_diskio_r      glibtop_get_proc_diskio_p
+#if GLIBTOP_SUID_PROC_IO
+#define glibtop_get_proc_io_r  glibtop_get_proc_io_p
 #else
-#define glibtop_get_proc_diskio_r      glibtop_get_proc_diskio_s
+#define glibtop_get_proc_io_r  glibtop_get_proc_io_s
 #endif
 
-void glibtop_get_proc_diskio_l (glibtop *server, glibtop_proc_diskio *buf, pid_t pid);
+void glibtop_get_proc_io_l (glibtop *server, glibtop_proc_io *buf, pid_t pid);
 
-#if GLIBTOP_SUID_PROC_DISKIO
-void _glibtop_init_proc_diskio_p (glibtop *server);
-void glibtop_get_proc_diskio_p (glibtop *server, glibtop_proc_diskio *buf, pid_t pid);
+#if GLIBTOP_SUID_PROC_IO
+void _glibtop_init_proc_io_p (glibtop *server);
+void glibtop_get_proc_io_p (glibtop *server, glibtop_proc_io *buf, pid_t pid);
 #else
-void _glibtop_init_proc_diskio_s (glibtop *server);
-void glibtop_get_proc_diskio_s (glibtop *server, glibtop_proc_diskio *buf, pid_t pid);
+void _glibtop_init_proc_io_s (glibtop *server);
+void glibtop_get_proc_io_s (glibtop *server, glibtop_proc_io *buf, pid_t pid);
 #endif
 
 
@@ -51,10 +51,10 @@ typedef struct _glibtop_proc_diskio glibtop_proc_diskio;
  * the storage layer. This is done at page-dirtying time.
  *
- * Process disk io data filled by glibtop_get_proc_diskio().
+ * Process disk io data filled by glibtop_get_proc_io().
  *
  */
diff --git a/sysdeps/common/default.c b/sysdeps/common/default.c
index 6987fb2..e3b096f 100644
--- a/sysdeps/common/default.c
+++ b/sysdeps/common/default.c
@@ -433,7 +433,7 @@ glibtop_get_proc_affinity(glibtop_proc_affinity *buf, pid_t pid)
 }
 
 /**
  * glibtop_get_proc_diskio: Get the disk io stats for the given pid
  * @buf: Buffer where the result will be given
  * @pid: Process id to get the io stats for
  *
@@ -442,7 +442,7 @@ glibtop_get_proc_affinity(glibtop_proc_affinity *buf, pid_t pid)
  * Returns: A list of processor ID of 'buf.number' elements.
  */
 void
-glibtop_get_proc_diskio(glibtop_proc_diskio *buf, pid_t pid)
+glibtop_get_proc_io(glibtop_proc_io *buf, pid_t pid)
 {
-       return glibtop_get_proc_diskio_l(glibtop_global_server, buf, pid);
+       return glibtop_get_proc_io_l(glibtop_global_server, buf, pid);
 }
@@ -433,7 +433,7 @@ glibtop_get_proc_affinity(glibtop_proc_affinity *buf, pid_t pid)
 
 /**
- * glibtop_get_proc_diskio: Get the disk io stats for the given pid
+ * glibtop_get_proc_io: Get the io stats for the given pid
  * @buf: Buffer where the result will be given
  * @pid: Process id to get the io stats for